@@ -25,6 +25,8 @@ static inline void r_str_rmch(char *s, char ch) {
 			memmove (s, s+1, strlen (s));
 	}
 }
+
+#define R_STR_DUP(x) ((x) ? strdup ((x)) : NULL)
 #define r_str_array(x,y) ((y>=0 && y<(sizeof(x)/sizeof(*x)))?x[y]:"")
 R_API const char *r_str_pad(const char ch, int len);
 R_API const char *r_str_rstr(const char *base, const char *p);
@@ -36,6 +38,8 @@ R_API bool r_str_range_in(const char *r, ut64 addr);
 R_API int r_str_len_utf8(const char *s);
 R_API int r_str_len_utf8char(const char *s, int left);
 R_API void r_str_filter_zeroline(char *str, int len);
+R_API int r_str_utf8_codepoint (const char* s, int left);
+R_API bool r_str_char_fullwidth (const char* s, int left);
 R_API int r_str_write(int fd, const char *b);
 R_API void r_str_ncpy(char *dst, const char *src, int n);
 R_API void r_str_sanitize(char *c);
@@ -52,6 +56,7 @@ R_API int r_str_bits(char *strout, const ut8 *buf, int len, const char *bitz);
 R_API int r_str_bits64(char *strout, ut64 in);
 R_API ut64 r_str_bits_from_string(const char *buf, const char *bitz);
 R_API int r_str_rwx(const char *str);
+R_API int r_str_replace_ch(char *s, char a, char b, bool g);
 R_API int r_str_replace_char(char *s, int a, int b);
 R_API int r_str_replace_char_once(char *s, int a, int b);
 R_API const char *r_str_rwx_i(int rwx);
@@ -67,6 +72,7 @@ R_API bool r_str_is_printable_incl_newlines(const char *str);
 R_API char *r_str_appendlen(char *ptr, const char *string, int slen);
 R_API char *r_str_newf(const char *fmt, ...);
 R_API char *r_str_newlen(const char *str, int len);
+R_API char *r_str_trunc_ellipsis(const char *str, int len);
 R_API const char *r_str_bool(int b);
 R_API const char *r_str_ansi_chrn(const char *str, int n);
 R_API int r_str_ansi_len(const char *str);
@@ -83,6 +89,7 @@ R_API char *r_str_word_get_first(const char *string);
 R_API char *r_str_trim(char *str);
 R_API char *r_str_trim_head(char *str);
 R_API const char *r_str_trim_ro(const char *str);
+R_API const char *r_str_trim_wp(const char *str);
 R_API char *r_str_trim_tail(char *str);
 R_API char *r_str_trim_head_tail(char *str);
 R_API ut32 r_str_hash(const char *str);
@@ -95,6 +102,8 @@ R_API const char *r_sub_str_rchr(const char *str, int start, int end, char chr);
 R_API char *r_str_ichr(char *str, char chr);
 R_API int r_str_ccmp(const char *dst, const char *orig, int ch);
 R_API int r_str_cmp(const char *dst, const char *orig, int len);
+R_API int r_str_casecmp(const char *dst, const char *orig);
+R_API int r_str_ncasecmp(const char *dst, const char *orig, size_t n);
 R_API int r_str_ccpy(char *dst, char *orig, int ch);
 R_API const char *r_str_get(const char *str);
 R_API const char *r_str_get2(const char *str);
@@ -124,7 +133,7 @@ R_API int r_str_re_replace(const char *str, const char *reg, const char *sub);
 R_API int r_str_unescape(char *buf);
 R_API char *r_str_escape(const char *buf);
 R_API char *r_str_escape_dot(const char *buf);
-R_API char *r_str_escape_latin1(const char *buf, bool show_asciidot, bool esc_bslash);
+R_API char *r_str_escape_latin1(const char *buf, bool show_asciidot, bool esc_bslash, bool colors);
 R_API char *r_str_escape_utf8(const char *buf, bool show_asciidot, bool esc_bslash);
 R_API char *r_str_escape_utf16le(const char *buf, int buf_size, bool show_asciidot, bool esc_bslash);
 R_API char *r_str_escape_utf32le(const char *buf, int buf_size, bool show_asciidot, bool esc_bslash);
@@ -134,6 +143,7 @@ R_API char *r_str_utf16_decode(const ut8 *s, int len);
 R_API int r_str_utf16_to_utf8(ut8 *dst, int len_dst, const ut8 *src, int len_src, int little_endian);
 R_API char *r_str_utf16_encode(const char *s, int len);
 R_API char *r_str_home(const char *str);
+R_API char *r_str_r2_prefix(const char *str);
 R_API int r_str_nlen(const char *s, int n);
 R_API int r_str_nlen_w(const char *s, int n);
 R_API int r_wstr_clen(const char *s);
@@ -155,7 +165,7 @@ R_API bool r_str_startswith(const char *str, const char *needle);
 R_API bool r_str_endswith(const char *str, const char *needle);
 R_API bool r_str_isnumber (const char *str);
 R_API const char *r_str_last (const char *in, const char *ch);
-R_API char* r_str_highlight(char *str, const char *word, const char *color);
+R_API char* r_str_highlight(char *str, const char *word, const char *color, const char *color_reset);
 R_API char *r_qrcode_gen(const ut8 *text, int len, bool utf8, bool inverted);
 R_API char *r_str_from_ut64(ut64 val);
 R_API void r_str_stripLine(char *str, const char *key);
